/*
 * Copyright (C) 2010, 2013, 2018 ARM Limited. All rights reserved.
 * 
 * This program is free software and is provided to you under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation, and any use by you of this program is subject to the terms of such GNU licence.
 * 
 * A copy of the licence is included with the program, and can also be obtained from Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 * @file mali_kernel_license.h
 * Defines for the macro MODULE_LICENSE.
 */

#ifndef __MALI_KERNEL_LICENSE_H__
#define __MALI_KERNEL_LICENSE_H__

#ifdef __cplusplus
extern "C" {
#endif

#define MALI_KERNEL_LINUX_LICENSE     "GPL"
#define MALI_LICENSE_IS_GPL 1

#ifdef __cplusplus
}
#endif

#endif /* __MALI_KERNEL_LICENSE_H__ */
